@@ -16,9 +16,9 @@ extends 'Perinci::CmdLine::Base';
 
 # put global variables alphabetically here
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-12-10'; # DATE
+our $DATE = '2021-12-11'; # DATE
 our $DIST = 'Perinci-CmdLine-Lite'; # DIST
-our $VERSION = '1.915'; # VERSION
+our $VERSION = '1.916'; # VERSION
 
 # when debugging, use this instead of the above because Mo doesn't give clear
 # error message if base class has errors.
@@ -430,11 +430,6 @@ sub hook_display_result {
     $self->display_result($r);
 }
 
-sub hook_after_run {
-    my ($self, $r) = @_;
-    $self->_unsetup_progress_output;
-}
-
 sub hook_after_get_meta {
     my ($self, $r) = @_;
 
@@ -656,7 +651,7 @@ Perinci::CmdLine::Lite - A Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-This document describes version 1.915 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2021-12-10.
+This document describes version 1.916 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2021-12-11.
 
 =head1 SYNOPSIS
 
