@@ -11,9 +11,9 @@ use IO::Interactive qw(is_interactive);
 
 # put global variables alphabetically here
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-12-10'; # DATE
+our $DATE = '2021-12-11'; # DATE
 our $DIST = 'Perinci-CmdLine-Lite'; # DIST
-our $VERSION = '1.915'; # VERSION
+our $VERSION = '1.916'; # VERSION
 
 sub meta {
     return {
@@ -203,7 +203,7 @@ sub on_run {
         $r->{res}[3]{'x.perinci.cmdline.base.exit_code'} = $exitcode;
     }
 
-    $self->_unsetup_progress_output;
+    $self->cmdline->_unsetup_progress_output;
 
     [201];
 }
@@ -223,7 +223,7 @@ Perinci::CmdLine::Plugin::Run::Normal - Normal run
 
 =head1 VERSION
 
-This document describes version 1.915 of Perinci::CmdLine::Plugin::Run::Normal (from Perl distribution Perinci-CmdLine-Lite), released on 2021-12-10.
+This document describes version 1.916 of Perinci::CmdLine::Plugin::Run::Normal (from Perl distribution Perinci-CmdLine-Lite), released on 2021-12-11.
 
 =head1 DESCRIPTION
 
